@@ -478,10 +478,10 @@ def vsi_path(path, vsi=None, archive=None):
     # an OGR VSI path (see cpl_vsi.h).
     if vsi:
         if archive:
-            result = '/'.join([
-                '/vsi{}'.format(vsi), archive.strip('/'), path.strip('/')])
+            result = '/vsi{0}/{1}{2}'.format(vsi, archive, path)
         else:
-            result = '/'.join(['/vsi{}'.format(vsi), path.strip('/')])
+            result = '/vsi{0}/{1}'.format(vsi, path)
     else:
         result = path
+
     return result
